# !/usr/bin/env python
# coding: utf-8

from dsframework.base.pipeline.predictables.predictable import ZIDS_Predictable


class generatedClass(ZIDS_Predictable):

    def __init__(self) -> None:
        super().__init__()

